.. _load_ref:

:mod:`biolearn.load`: Data Loading Utilities
==============================================

.. automodule:: biolearn.load
   :no-members:
   :no-inherited-members:

**Functions**:

.. currentmodule:: biolearn.load

.. autosummary::
   :toctree: generated/
   :template: function.rst

   load_nhanes
   load_fhs